Attribute VB_Name = "VBMPUSBAPI"
Option Explicit

'Functions for use in Visual Basic from MPUSBAPI.DLL


'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'  MPUSBGetDLLVersion : get mpusbapi.dll revision level
'
'  Input:
'      None
'  Output:
'      32-bit revision level MMMMmmmm
'
Public Declare Function MPUSBGetDLLVersion Lib "mpusbapi.dll" () As Long


'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'  MPUSBGetDeviceCount : Returns the number of devices with matching VID & PID
'
Public Declare Function MPUSBGetDeviceCount Lib "mpusbapi.dll" (ByVal pVID_PID As String) As Long


'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'  MPUSBOpen : Returns the handle to the endpoint pipe with matching VID & PID
'
'  All pipes are opened with the FILE_FLAG_OVERLAPPED attribute.
'  This allows MPUSBRead,MPUSBWrite, and MPUSBReadInt to have a time-out value.
'
'  Note: Time-out value has no meaning for Isochronous pipes.
'
'  instance - An instance number of the device to open.
'             Typical usage is to call MPUSBGetDeviceCount first to find out
'             how many instances there are.
'             It is important to understand that the driver is shared among
'             different devices. The number of devices returned by
'             MPUSBGetDeviceCount could be equal to or less than the number
'             of all the devices that are currently connected & using the
'             generic driver.
'
'             Example:
'             if there are 3 device with the following PID&VID connected:
'             Device Instance 0, VID 0x04d8, PID 0x0001
'             Device Instance 1, VID 0x04d8, PID 0x0002
'             Device Instance 2, VID 0x04d8, PID 0x0001
'
'             If the device of interest has VID = 0x04d8 and PID = 0x0002
'             Then MPUSBGetDeviceCount will only return '1'.
'             The calling function should have a mechanism that attempts
'             to call MPUSBOpen up to the absolute maximum of MAX_NUM_MPUSB_DEV
'             (MAX_NUM_MPUSB_DEV is defined in _mpusbapi.h).
'             It should also keep track of the number of successful calls
'             to MPUSBOpen(). Once the number of successes equals the
'             number returned by MPUSBGetDeviceCount, the attempts should
'             be aborted because there will no more devices with
'             a matching vid&pid left.
'
'  pVID_PID - A string containing the PID&VID value of the target device.
'             The format is "vid_xxxx&pid_yyyy". Where xxxx is the VID value
'             in hex and yyyy is the PID value in hex.
'             Example: If a device has the VID value of 0x04d8 and PID value
'                      of 0x000b, then the input string should be:
'                      "vid_04d8&pid_000b"
'
'  pEP      - A string of the endpoint number on the target endpoint to open.
'             The format is "\\MCHP_EPz". Where z is the endpoint number in
'             decimal.
'             Example: "\\MCHP_EP1"
'
'             This arguement can be NULL. A NULL value should be used to
'             create a handles for non-specific endpoint functions.
'             MPUSBRead, MPUSBWrite, MPUSBReadInt are endpoint specific
'             functions.
'             All others are not.
'             Non-specific endpoint functions will become available in the
'             next release of the DLL.
'
'             Note: To use MPUSBReadInt(), the format of pEP has to be
'                   "\\MCHP_EPz_ASYNC". This option is only available for
'                   an IN interrupt endpoint. A data pipe opened with the
'                   "_ASYNC" keyword would buffer the data at the interval
'                   specified in the endpoint descriptor upto the maximum of
'                   100 data sets. Any data received after the driver buffer
'                   is full will be ignored.
'                   The user application should call MPUSBReadInt() often
'                   enough so that the maximum limit of 100 is never reached.
'
'  dwDir    - Specifies the direction of the endpoint.
'             Use MP_READ for MPUSBRead, MPSUBReadInt
'             Use MP_WRITE for MPUSBWrite
'
'  dwReserved Future Use
'
'  Summary of transfer type usage:
'  ============================================================================
'  Transfer Type       Functions                       Time-Out Applicable?
'  ============================================================================
'  Interrupt - IN      MPUSBRead, MPUSBReadInt         Yes
'  Interrupt - OUT     MPUSBWrite                      Yes
'  Bulk - IN           MPUSBRead                       Yes
'  Bulk - OUT          MPUSBWrite                      Yes
'  Isochronous - IN    MPUSBRead                       No
'  Isochronous - OUT   MPUSBWrite                      No
'  ============================================================================
'
Public Declare Function MPUSBOpen Lib "mpusbapi.dll" _
                (ByVal instance As Long, ByVal pVID_PID As String, ByVal pEP As String, ByVal dwDir As Long, ByVal dwReserved As Long) As Long



'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'  MPUSBClose : closes a given handle.
'
Public Declare Function MPUSBClose Lib "mpusbapi.dll" (ByVal handle As Long) As Long



'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'  MPUSBRead :
'
'  handle  - Identifies the endpoint pipe to be read. The pipe handle must
'            have been created with MP_READ access attribute.
'
'  pData   - Points to the buffer that receives the data read from the pipe.
'
'  dwLen   - Specifies the number of bytes to be read from the pipe.
'
'  pLength - Points to the number of bytes read. MPUSBRead sets this value to
'            zero before doing any work or error checking.
'
'  dwMilliseconds
'          - Specifies the time-out interval, in milliseconds. The function
'            returns if the interval elapses, even if the operation is
'            incomplete. If dwMilliseconds is zero, the function tests the
'            data pipe and returns immediately. If dwMilliseconds is INFINITE,
'            the function's time-out interval never elapses.
'
Public Declare Function MPUSBRead Lib "mpusbapi.dll" _
                 (ByVal handle As Long, ByVal pData As Long, ByVal dwLen As Long, ByRef pLength As Long, ByVal dwMilliseconds As Long) As Long
                 


'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'  MPUSBWrite :
'
'  handle  - Identifies the endpoint pipe to be written to. The pipe handle
'            must have been created with MP_WRITE access attribute.
'
'  pData   - Points to the buffer containing the data to be written to the pipe.
'
'  dwLen   - Specifies the number of bytes to write to the pipe.
'
'  pLength - Points to the number of bytes written by this function call.
'            MPUSBWrite sets this value to zero before doing any work or
'            error checking.
'
'  dwMilliseconds
'          - Specifies the time-out interval, in milliseconds. The function
'            returns if the interval elapses, even if the operation is
'            incomplete. If dwMilliseconds is zero, the function tests the
'            data pipe and returns immediately. If dwMilliseconds is INFINITE,
'            the function's time-out interval never elapses.
'
Public Declare Function MPUSBWrite Lib "mpusbapi.dll" _
                (ByVal handle As Long, ByVal pData As Long, ByVal dwLen As Long, ByRef pLength As Long, ByVal dwMilliseconds As Long) As Long
                


'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'  MPUSBReadInt :
'
'  handle  - Identifies the endpoint pipe to be read. The pipe handle must
'            have been created with MP_READ access attribute.
'
'  pData   - Points to the buffer that receives the data read from the pipe.
'
'  dwLen   - Specifies the number of bytes to be read from the pipe.
'
'  pLength - Points to the number of bytes read. MPUSBRead sets this value to
'            zero before doing any work or error checking.
'
'  dwMilliseconds
'          - Specifies the time-out interval, in milliseconds. The function
'            returns if the interval elapses, even if the operation is
'            incomplete. If dwMilliseconds is zero, the function tests the
'            data pipe and returns immediately. If dwMilliseconds is INFINITE,
'            the function's time-out interval never elapses.
'
Public Declare Function MPUSBReadInt Lib "mpusbapi.dll" _
                (ByVal handle As Long, ByVal pData As Long, ByVal dwLen As Long, ByRef pLength As Long, ByVal dwMilliseconds As Long) As Long


'Functions and Data required from WIN32 API
Public Const INVALID_HANDLE_VALUE = -1
Public Const ERROR_INVALID_HANDLE = 6&

Public Declare Function GetLastError Lib "kernel32" () As Long


'Constants for connecting to Microchip firmware
Public Const vid_pid = "vid_04d8&pid_000b"
Public Const out_pipe = "\MCHP_EP1"
Public Const in_pipe = "\MCHP_EP1"

Public Const MPUSB_FAIL = 0
Public Const MPUSB_SUCCESS = 1

Public Const MP_WRITE = 0
Public Const MP_READ = 1

'Declare the IN PIPE and OUT PIPE Public variables
Public myInPipe As Long, myOutPipe As Long
